<?php
namespace Fiscal\Logic\Impostos\Exceptions;

/**
 * A nota fiscal e/ou os produtos estao sem incidencia sem incidencia dos impostos obrigatorios.
 */
class ImpostoJaCadastrado extends \Fiscal\Logic\Exception
{

    private $messageName;
    
    public function __construct($messageName, $param = null, $code = 0, \Exception $previous = null) {
        parent::__construct($messageName, $code, $previous);
        $this->messageName = $messageName;

        if ($param)
            parent::setParams($param);
    }
    
    /**
     * Retorna o nome da mensagem cadastrada no Setforms para esta excecao.
     *
     * @return string
     */
    public static function impostoJaCadastrado() {
        throw new self('msg_impostoJaCadastrado');
    }

    /**
     * Erro de imposto já cadastrado para o CFOP, CST e Código Fiscal informados
     * @throws ImpostoJaCadastrado
     */
    public static function impostoCadastradoCFOP() {
        throw new self (tk_get_message_by_name('msg_pbi00028_impostoCadastradoCFOP'));
    }

    /**
     * Erro de imposto já cadastrado para o Tipo de Operação, CFOP, CST e Código Fiscal informados
     * @throws ImpostoJaCadastrado
     */
    public static function impostoCadastradoOperacao() {
        throw new self (tk_get_message_by_name('msg_pbi00028_impostoCadastradoOperacao'));
    }

    /**
     * Erro de mapa já cadastrado para o imposto
     * @throws ImpostoJaCadastrado
     */
    public static function impostoCadastradoMapa() {
        throw new self ('msg_pbi00154_impostoCadastradoMapa');
    }

    public function getMessageName()
    {
        return $this->messageName;
    }

}