/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: NUTRIENTE_DO_PRATO_PLA

Descrio:
Clculo dos Nutrientes dos pratos e gravao na tabela NUTRTRAB.

P_FILIAL     - Codigo da Filial.
P_SERVICOS   - String contendo sequencia de Servios a serem calculados.
P_NUTRIENTES - String contendo Nutrientes a serem calculados.
P_NRSEQUNUTR - Nmero sequencial a ser utilizado para gravao dos dados.
P_IDNDPCAL   - Indicador de calculo do NDPCal.
P_CDPRATOINI - Codigo do prato inicial.
P_CDPRATOFIN - Codigo do prato final.


Criao:
02/03/98 - Zed

Manutenes:
05/03/99 - Ederson - Reviso geral.

****************************************************************
             CORREO DO CLCULO DO NDPCAL%
****************************************************************
A frmula usada para clculo do NDPCal% :

NDPCAL% = NPU * Sum(Protenas) * 4
          ------------------------
                    VCT

onde:

NPU = Somatrio das protenas dos componentes da receita multiplicados
      pelo Fator de Clculo de NDPCAL, informado na tela de parametrizao
      por grupo de produtos, sendo 0,7 para alimentos de origem animal;
      0,6 para leguminosas e 0,5 para cereais, frutas e outros vegetais.
Sum(Protenas) = Somatrio das protenas dos componentes da receita
VCT = "Valor Calrico Total" = Soma(carboidratos) x 4 +
                               Soma(lipdeos)    x 9  +
                               Soma(protenas)   x 4  +
                               Soma(lcoois)     x 7
****************************************************************
*/

IF EXISTS(SELECT name FROM sysobjects
          WHERE name = 'NUTRIENTE_DO_PRATO_PLA' AND type = 'P')
  DROP PROCEDURE NUTRIENTE_DO_PRATO_PLA
  GO

CREATE PROCEDURE NUTRIENTE_DO_PRATO_PLA @P_FILIAL     VARCHAR(4),
                                        @P_SERVICOS   VARCHAR(2000),
                                        @P_NUTRIENTES VARCHAR(2000),
                                        @P_NRSEQUNUTR VARCHAR(10),
                                        @P_IDNDPCAL   VARCHAR,
                                        @P_CDPRATOINI VARCHAR(10),
                                        @P_CDPRATOFIN VARCHAR(10)

AS

       DECLARE @V_NRSEQUNUTR    VARCHAR(10);
       DECLARE @V_CDFILINUTR     VARCHAR(4);
       DECLARE @V_CDSERVNUTR     VARCHAR(3);
       DECLARE @V_DTREFENUTR     DATETIME;
       DECLARE @V_CDDIETNUTR     VARCHAR(4);
       DECLARE @V_NRSEQPRATNUT   SMALLINT;
       DECLARE @V_CDTPPRATNUTR   VARCHAR(2);
       DECLARE @V_CDFAPRATNUTR   VARCHAR(4);
       DECLARE @V_CDPRATNUTR     VARCHAR(10);
       DECLARE @V_CDPRODNUTR     VARCHAR(10);
       DECLARE @V_QTCARBOIDRATO NUMERIC(12,5);
       DECLARE @V_QTPROTEINA    NUMERIC(12,5);
       DECLARE @V_QTLIPIDEO     NUMERIC(12,5);
       DECLARE @V_QTALCOOL      NUMERIC(12,5);
       DECLARE @V_QTCALORIA     NUMERIC(12,5);

BEGIN

   INSERT INTO NUTRTRAB
      (NRSEQUNUTR,
       CDFILINUTR,
       CDSERVNUTR,
       DTREFENUTR,
       CDDIETNUTR,
       NRSEQPRATNUT,
       CDTPPRATNUTR,
       CDFAPRATNUTR,
       CDPRATNUTR,
       CDPRODNUTR,
       CDNUTRCALC,
       QTPRODNUTR,
       QTNUTRCALC,
       QTPROTLIQU,
       VRCALORNUTR,
       VRPECONSNUTR)
   SELECT
      @P_NRSEQUNUTR,
      SE.CDFILIAL,
      SE.CDSERVFILI,
      '01/01/01',
      'XXXX',
      0,
      'XX',
      RS.CDFILAUXPRAT,
      RS.CDPRATO,
      RS.CDPRODUTO,
      NP.CDNUTRIENTE,
      RS.QTCALCNUTRSE AS QTPRODUTO,
      NP.QTNUTRPROD * 10 * ISNULL((CASE PRODFILI.VRPESOUNIDFI WHEN 0 THEN PR.VRPESOUNID ELSE PRODFILI.VRPESOUNIDFI END), PR.VRPESOUNID) * RS.QTCALCNUTRSE,
      0,
      0,
      100
   FROM
      SERVICO SE, RECESERV RS, NUTRPROD NP, PRODUTO PR, PRODFILI
   WHERE
      (SE.CDFILIAL = @P_FILIAL)                                AND
      (CHARINDEX(SE.CDSERVFILI, @P_SERVICOS) <> 0)             AND
      (SE.CDFILIAL = RS.CDFILIAL)                              AND
      (SE.CDSERVFILI = RS.CDSERVFILI)                          AND
      (RS.CDFILAUXPRAT = 'P' OR RS.CDFILAUXPRAT = SE.CDFILIAL) AND
      (RS.CDPRATO BETWEEN @P_CDPRATOINI AND @P_CDPRATOFIN)     AND
      (CHARINDEX(NP.CDNUTRIENTE, @P_NUTRIENTES) <> 0)          AND
      (RS.CDPRODUTO = NP.CDPRODUTO)                            AND
      (RS.CDPRODUTO = PR.CDPRODUTO)                            AND
      (PRODFILI.CDFILIAL = SE.CDFILIAL)                        AND
      (PRODFILI.CDPRODUTO = RS.CDPRODUTO)
   UNION
   SELECT
      @P_NRSEQUNUTR,
      SE.CDFILIAL,
      SE.CDSERVFILI,
      '01/01/01',
      'XXXX',
      0,
      'XX',
      RF.CDFILAUXPRAT,
      RF.CDPRATO,
      RF.CDPRODUTO,
      NP.CDNUTRIENTE,
      RF.QTCALCNUTRLO AS QTPRODUTO,
      NP.QTNUTRPROD * 10 * ISNULL((CASE PRODFILI.VRPESOUNIDFI WHEN 0 THEN PR.VRPESOUNID ELSE PRODFILI.VRPESOUNIDFI END), PR.VRPESOUNID) * RF.QTCALCNUTRLO,
      0,
      0,
      100
   FROM
      SERVICO SE, RECEFILI RF, NUTRPROD NP, PRODUTO PR, PRODFILI
   WHERE
      (SE.CDFILIAL = @P_FILIAL)                                AND
      (CHARINDEX(SE.CDSERVFILI, @P_SERVICOS) <> 0)             AND
      (SE.CDFILIAL = RF.CDFILIAL)                              AND
      (RF.CDFILAUXPRAT = 'P' OR RF.CDFILAUXPRAT = SE.CDFILIAL) AND
      (RF.CDPRATO BETWEEN @P_CDPRATOINI AND @P_CDPRATOFIN)     AND
      (CHARINDEX(NP.CDNUTRIENTE, @P_NUTRIENTES) <> 0)          AND
      (RF.CDPRODUTO = NP.CDPRODUTO)                            AND
      (RF.CDPRODUTO = PR.CDPRODUTO)                            AND
      (PRODFILI.CDFILIAL = SE.CDFILIAL)                        AND
      (PRODFILI.CDPRODUTO = RF.CDPRODUTO)                      AND
      NOT EXISTS (SELECT
                     CDPRATO
                  FROM
                     RECESERV
                  WHERE
                     (CDFILAUXPRAT = RF.CDFILAUXPRAT) AND
                     (CDPRATO      = RF.CDPRATO)      AND
                     (CDFILIAL     = SE.CDFILIAL)     AND
                     (CDSERVFILI   = SE.CDSERVFILI)
                  )
   UNION
   SELECT
      @P_NRSEQUNUTR,
      SE.CDFILIAL,
      SE.CDSERVFILI,
      '01/01/01',
      'XXXX',
      0,
      'XX',
      RP.CDFILAUXPRAT,
      RP.CDPRATO,
      RP.CDPRODUTO,
      NP.CDNUTRIENTE,
      RP.QTCALCNUTRPR AS QTPRODUTO,
      NP.QTNUTRPROD * 10 * ISNULL((CASE PRODFILI.VRPESOUNIDFI WHEN 0 THEN PR.VRPESOUNID ELSE PRODFILI.VRPESOUNIDFI END), PR.VRPESOUNID) * RP.QTCALCNUTRPR,
      0,
      0,
      100
   FROM
      SERVICO SE, RECEPADR RP, NUTRPROD NP, PRODUTO PR, PRODFILI
   WHERE
      (SE.CDFILIAL = @P_FILIAL)                          AND
      (CHARINDEX(SE.CDSERVFILI, @P_SERVICOS) <> 0)       AND
      (RP.CDFILAUXPRAT = 'P')                            AND
      (RP.CDPRATO BETWEEN @P_CDPRATOINI AND @P_CDPRATOFIN) AND
      (CHARINDEX(NP.CDNUTRIENTE, @P_NUTRIENTES) <> 0)    AND
      (RP.CDPRODUTO = NP.CDPRODUTO)                      AND
      (RP.CDPRODUTO = PR.CDPRODUTO)                      AND
      (PRODFILI.CDFILIAL = SE.CDFILIAL)                  AND
      (PRODFILI.CDPRODUTO = RP.CDPRODUTO)                AND
      NOT EXISTS (SELECT
                     CDPRATO
                  FROM
                     RECEFILI
                  WHERE
                     (CDFILAUXPRAT = RP.CDFILAUXPRAT) AND
                     (CDPRATO      = RP.CDPRATO)      AND
                     (CDFILIAL     = SE.CDFILIAL)
                  ) AND
      NOT EXISTS (SELECT
                     CDPRATO
                  FROM
                     RECESERV
                  WHERE
                     (CDFILAUXPRAT = RP.CDFILAUXPRAT) AND
                     (CDPRATO      = RP.CDPRATO)      AND
                     (CDFILIAL     = SE.CDFILIAL)     AND
                     (CDSERVFILI   = SE.CDSERVFILI)
   );

   /* ------------------------- CALCULO DO DNPCal --------------------------- */
   IF @P_IDNDPCAL = 'S'
   BEGIN
      /* ---------------- GRAVA O VALOR DE PROTEINA LIQUIDA ----------------- */
      UPDATE
         NUTRTRAB
      SET
         QTPROTLIQU = (SELECT
                          ISNULL(MAX(VRFATCALNDPC) * QTNUTRCALC,0)
                       FROM
                          NDPCAL
                       WHERE
                          CDPRODUTO = (SELECT
                                          MAX(CDPRODUTO)
                                       FROM
                                          NDPCAL
                                       WHERE
                                          CHARINDEX(NUTRTRAB.CDPRODNUTR,CDPRODUTO) = 1
                                      )
                       )
      WHERE
         CDNUTRCALC = (SELECT MAX(CDPROTEINA) FROM PARAMGERAL) AND
         NRSEQUNUTR = @P_NRSEQUNUTR;

      /* --------------------- GRAVA O VALOR DE CALORIAS -------------------- */
      UPDATE
         NUTRTRAB
      SET
         VRCALORNUTR = QTNUTRCALC
      WHERE
         CDNUTRCALC = (SELECT MAX(CDCALORIAS) FROM PARAMGERAL) AND
         NRSEQUNUTR = @P_NRSEQUNUTR;

   END;
END;
GO
